@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""A base class for implementing steps."""
+"""A base class for implementing sieves."""
 
 import abc
 from typing import Generator
